"""
Copyright 2023-2023 VMware Inc.
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import click
from hcs_cli.service import portal
import hcs_core.sglib.cli_options as cli
from hcs_core.ctxp import recent


@click.command()
@click.option("--search", "-s", type=str, required=False, help="Search condition")
@click.option(
    "--all/--default", "-a/-d", type=bool, default=False, help="Specify whether to show deleted and internal pools."
)
@cli.org_id
def list(org: str, all: bool, **kwargs):
    """List pools"""
    org_id = cli.get_org_id(org)
    ret = portal.pool.list(org_id, exclude_disabled_pools=not all, include_internal_pools=all, **kwargs)
    recent.helper.default_list(ret, "pool")
    return ret
